@@ -1,6 +1,6 @@
-### entropy.empirical.R  (2008-08-20)
+### entropy.empirical.R  (2008-09-28)
 ###
-###    Empirical entropy estimator
+###    Empirical entropy and mutual information estimator
 ###
 ### Copyright 2008 Korbinian Strimmer
 ###
@@ -35,3 +35,9 @@ freqs.empirical = function(y)
   return( y/sum(y) )
 }
 
+# empirical mutual information
+mi.empirical = function(y, unit=c("log", "log2", "log10"))
+{
+  return( mi.plugin(freqs.empirical(y), unit=unit) )
+}
+
